FacetProbe

Struct FacetProbe 

pub struct FacetProbe<'mem, 'facet> { /* private fields */ }
The container that stores a MaybeMut of the type T that should be shown in the Ui

Implementations

Source

impl<'mem, 'facet> FacetProbe<'mem, 'facet>

pub fn readonly(self, readonly: bool) -> Self

pub fn expand_all(self, expand_all: bool) -> Self

pub fn with_header(self, label: impl Into<WidgetText>) -> Self

pub fn with_id_source(self, id_source: impl Hash) -> Self

Set a stable egui id source for this probe.

Use this when the probe can move in the UI hierarchy (e.g. draggable tabs), so collapse/expand state remains stable.

pub unsafe fn force_reborrow(self) -> Self

Safety

If used, there is a high chance what you do is unsound.

If you use this, you will have to manually ensure your variances are okay for use with reborrowing. Normally, this is determined by facet but there may be cases where a type does not implement Facet or has opaque parts that would (if used with facet) be ok.

pub fn new_peek(value: Peek<'mem, 'facet>) -> Self

pub fn new_poke(value: Poke<'mem, 'facet>) -> Self

pub fn new<T>(value: impl Into<MaybeMutT<'mem, T>>) -> Self
where T: Facet<'facet> + 'mem,

pub fn show<'lock>(self, ui: &mut Ui) -> Response
where 'mem: 'lock,

Methods from Deref<Target = MaybeMut<'mem, 'facet>>

pub fn as_peek(&'mem self) -> Peek<'mem, 'facet>

Returns a readonly/immutable version of the inner type

pub fn shape(&self) -> &'static Shape

Returns the Shape of the underlying type

The Shape is the same for Mut and Not